@@ -1,21 +1,10 @@
-"""
-This program and the accompanying materials are made available under the terms of the
-Eclipse Public License v2.0 which accompanies this distribution, and is available at
-https://www.eclipse.org/legal/epl-v20.html
-SPDX-License-Identifier: EPL-2.0
-
-Copyright Contributors to the Zincware Project.
-
-Description:
-"""
-
 import re
 from abc import ABC, abstractmethod
+from functools import partial
 from typing import Callable
 
-
-class DescriptorMissing(Exception):
-    pass
+from zntrack import utils
+from zntrack.core.dvcgraph import filter_ZnTrackOption
 
 
 class MetaData(ABC):
@@ -61,8 +50,6 @@ class MetaData(ABC):
         https://stackoverflow.com/questions/30104047/how-can-i-decorate-an-instance-method-with-a-decorator-class
         """
 
-        from functools import partial
-
         return partial(self.__call__, instance)
 
     def save_metadata(self, cls, value):
@@ -77,14 +64,26 @@ class MetaData(ABC):
         cls: the class that has the cls.metadata ZnTrackOption
         value:
             Any value that should be saved
+
+        Raises
+        ------
+        DescriptorMissing:
+            If the Node does not contain a <zn.metadata> descriptor
         """
 
         try:
             metadata_attr, metadata = next(
-                iter(cls._descriptor_list.filter(zntrack_type="metadata").items())
+                iter(
+                    filter_ZnTrackOption(
+                        data=cls._descriptor_list,
+                        cls=cls,
+                        zn_type=utils.ZnTypes.METADATA,
+                        allow_none=True,
+                    ).items()
+                )
             )
         except StopIteration as error:
-            raise DescriptorMissing(
+            raise utils.exceptions.DescriptorMissing(
                 "Could not find a metadata descriptor. Please add zn.metadata()!"
             ) from error
         if metadata is None:
