@@ -4,18 +4,18 @@ import pathlib
 import pandas as pd
 
 from zntrack import utils
-from zntrack.core.zntrackoption import ZnTrackOption
+from zntrack.dvc.custom_base import PlotsModifyOption
 
 log = logging.getLogger(__name__)
 
 
-class plots(ZnTrackOption):
+class plots(PlotsModifyOption):
     dvc_option = utils.DVCOptions.PLOTS_NO_CACHE.value
-    zn_type = utils.ZnTypes.RESULTS
+    zn_type = utils.ZnTypes.PLOTS
 
     def get_filename(self, instance) -> pathlib.Path:
         """Overwrite filename to csv"""
-        return pathlib.Path("nodes", instance.node_name, f"{self.dvc_option}.csv")
+        return pathlib.Path("nodes", instance.node_name, f"{self.name}.csv")
 
     def save(self, instance):
         """Save value with pd.DataFrame.to_csv"""
@@ -30,10 +30,7 @@ class plots(ZnTrackOption):
             )
 
         if value.index.name is None:
-            raise ValueError(
-                "pd.DataFrame must have an index name! You can set the name via"
-                " DataFrame.index.name = <index name>."
-            )
+            value.index.name = "index"
 
         file = self.get_filename(instance)
         file.parent.mkdir(exist_ok=True, parents=True)
